Crate diem_transaction_builder

Crate diem_transaction_builder 

Modules

error_explain
A module for looking up the human-readable explanation of a Diem Move transaction abort code.
stdlib
Conversion library between a structured representation of a Move script call (ScriptCall) and the standard BCS-compatible representation used in Diem transactions (Script).